summaryrefslogtreecommitdiff
path: root/libnetfs/netfs.h
diff options
context:
space:
mode:
authorMarcus Brinkmann <marcus@gnu.org>2000-12-30 20:08:31 +0000
committerMarcus Brinkmann <marcus@gnu.org>2000-12-30 20:08:31 +0000
commit957e2e91d0d763550f22f177354bc7ffd627ecca (patch)
tree433a37d801f928503b28f8be0771c9de557b1530 /libnetfs/netfs.h
parentfc97341f492be10f20e4c8a639614e0230d53471 (diff)
2000-12-30 Marcus Brinkmann <marcus@gnu.org>
* netfs.h: Merge Neals words into documentation of netfs_nput, netfs_nrele, netfs_nref.
Diffstat (limited to 'libnetfs/netfs.h')
-rw-r--r--libnetfs/netfs.h15
1 files changed, 9 insertions, 6 deletions
diff --git a/libnetfs/netfs.h b/libnetfs/netfs.h
index b7cb9aaf..013ea859 100644
--- a/libnetfs/netfs.h
+++ b/libnetfs/netfs.h
@@ -354,16 +354,19 @@ struct protid *netfs_make_protid (struct peropen *po, struct iouser *user);
struct peropen *netfs_make_peropen (struct node *, int,
struct peropen *context);
/* Add a reference to locked node NP. */
void netfs_nref (struct node *np);
-/* Releases a node. Drops a reference to unlocked node NP. If this
- was the last reference, drops the node. */
+/* Releases a node. Drops a reference to node NP, which must not be
+ locked by the caller. If this was the last reference, drops the
+ node. The node cannot be used again without first obtaining a
+ reference to it. */
void netfs_nrele (struct node *np);
-/* Puts a node back. Drops a reference to the locked node NP (and
- releases the lock, too). If this was the last reference, drops the
- node. */
+/* Puts a node back. Drops a reference to the node NP, which must be
+ locked by the caller (this lock will be released by netfs_nput).
+ If this was the last reference, drops the node. The node cannot be
+ used again without first obtaining a reference to it. */
void netfs_nput (struct node *np);
/* Called internally when no more references to node NP exist. */
@@ -354,16 +354,19 @@ struct protid *netfs_make_protid (struct peropen *po, struct iouser *user);
struct peropen *netfs_make_peropen (struct node *, int,
struct peropen *context);
-/* Add a reference to locked node NP. */
+/* Add a reference to node NP, which must be locked by the caller. */
void netfs_nref (struct node *np);